@@ -211,8 +211,8 @@ class Settings(object):
 
         By default it produces two directories:
 
-            * ``/etc/{appname}/templates``
-            * ``/usr/share/{appname}/templates``
+            * ``"/etc/{appname}/templates"``
+            * ``"/usr/share/{appname}/templates"``
 
         The first one is provided for administrators that may wish to override
         one or more templates in a local installation for any purpose. The
@@ -223,6 +223,23 @@ class Settings(object):
             "/usr/share/{appname}/templates/".format(appname=self._appname))
         return self._settings.get("TEMPLATE_DIRS", default)
 
+    @property
+    def STATICFILES_DIRS(self):
+        """
+        Similar to TEMPLATE_DIRS but only for static files shipped with each application.
+
+        Bridge for the settings file STATICFILES_DIRS property.
+
+        By default it produces one directory:
+
+            * ``"/usr/share/{appname}/htdocs/"``
+
+        """
+        default = (
+            (self._appname, "/usr/share/{appname}/htdocs/".format(appname=self._appname)),
+        )
+        return self._settings.get("STATICFILES_DIRS", default)
+
     @property
     def ADMINS(self):
         """
